@@ -77,3 +77,36 @@ testthat::test_that("multivar works as part of a tier match", {
   result$matches[tier == "c"]
   expect_is(result$matches, "data.table")
 })
+testthat::test_that("multivar works with wgt_jaccard", {
+  corp_data1_test <- copy(fedmatch::corp_data1)
+  corp_data2_test <- copy(fedmatch::corp_data2)
+  corp_data1_test[, id_1 := seq(1, .N)]
+  corp_data2_test[, id_2 := seq(1, .N)]
+  # corp_data1_test
+  corp_data2_test[, Country := country]
+  corp_data2_test[, Company := Name]
+  set.seed(111)
+  fake_result_table <- data.table(
+    match = c(rep(1, .25e5), rep(0, .25e5), rep(1, .5e5)),
+    Company_compare = seq(.00001, 1, .00001),
+    Country_compare = sample(c(1, 0), 1e5, replace = TRUE)
+  )
+
+  logit_model <- glm(match ~ Company_compare + Country_compare,
+                     family = "binomial",
+                     data = fake_result_table
+  )
+  # corp_data2_test
+  # fake_result_table
+  summary(logit_model)
+  # class(logit_model)
+  result <- multivar_match(corp_data1_test, corp_data2_test,
+                           by = c("Country", "Company"), unique_key_1 = "id_1",
+                           unique_key_2 = "id_2", logit = logit_model,
+                           compare_type = c("indicator", "wgt_jaccard_dist"),
+                           wgts = NULL, nthread = 1,
+                           suffixes = c("_1", "_2")
+  )
+  result
+  expect_is(result, "data.table")
+})
